===========
ripcord-api
===========

---------------------------
Server for the Ripcord APIs
---------------------------

:Author: paul.belanger@polybeacon.com
:Date: |today|
:Copyright: PolyBeacon, Inc
:Version: |version|
:Manual section: 1

SYNOPSIS
========

  ripcord-api  [options]

DESCRIPTION
===========

ripcord-api is a server daemon that serves the ripcord APIs

OPTIONS
=======

 **General options**

FILES
=====

* /etc/ripcord/ripcord.conf

SEE ALSO
========

* `ripcord <https://github.com/kickstandproject/ripcord>`__

BUGS
====

* Ripcord is sourced in Github so you can view current bugs at `ripcord <https://github.com/kickstandproject/ripcord>`__
